# Warning

Do not add an **init.py** to this directorty. `nv_one_logger` is a namespace package. This makes it possible to have multiple Python projects that define subpackages and code under the package `nv_one_logger.`.
